@@ -2,9 +2,7 @@
 //
 // The JACK Driver for the Core Audio Engine component of Rivendell
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: cae_jack.cpp,v 1.50 2008/07/18 20:06:10 fredg Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +25,8 @@
 #include <qsignalmapper.h>
 
 #include <rd.h>
+#include <rddb.h>
+#include <rdescape_string.h>
 #include <rdringbuffer.h>
 #include <rdprofile.h>
 #include <rdmeteraverage.h>
@@ -40,6 +40,7 @@
 jack_client_t *jack_client;
 RDMeterAverage *jack_input_meter[RD_MAX_PORTS][2];
 RDMeterAverage *jack_output_meter[RD_MAX_PORTS][2];
+RDMeterAverage *jack_stream_output_meter[RD_MAX_STREAMS][2];
 //volatile jack_default_audio_sample_t jack_input_meter[RD_MAX_PORTS][2];
 //volatile jack_default_audio_sample_t jack_output_meter[RD_MAX_PORTS][2];
 volatile jack_default_audio_sample_t 
@@ -79,6 +80,7 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   unsigned n=0;
   jack_default_audio_sample_t in_meter[2];
   jack_default_audio_sample_t out_meter[2];
+  jack_default_audio_sample_t stream_out_meter;
 
   //
   // Ensure Buffers are Valid
@@ -125,64 +127,66 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   for(int i=0;i<RD_MAX_PORTS;i++) {
     if(jack_recording[i]) {
       switch(jack_input_channels[i]) {
-          case 1: // mono
-            for(unsigned j=0;j<nframes;j++) {
-              switch(jack_input_mode[jack_card_process][i]) {
-                  case 3: // R only
-                    jack_callback_buffer[j]=jack_input_volume[i]*
-                      jack_input_buffer[i][1][j];
-                    break;
-                  case 2: // L only
-                    jack_callback_buffer[j]=jack_input_volume[i]*
-                      jack_input_buffer[i][0][j];
-                    break;
-                  case 1: // swap, sum R+L
-                  case 0: // normal, sum L+R
-                  default:
-                    jack_callback_buffer[j]=jack_input_volume[i]*
-                      (jack_input_buffer[i][0][j]+jack_input_buffer[i][1][j]);
-                    break;
-              }
-            } // for nframes
-            n=jack_record_ring[i]->
-              write((char *)jack_callback_buffer,
-                    nframes*sizeof(jack_default_audio_sample_t))/
-                sizeof(jack_default_audio_sample_t);
-            break;
+      case 1: // mono
+	for(unsigned j=0;j<nframes;j++) {
+	  switch(jack_input_mode[jack_card_process][i]) {
+	  case 3: // R only
+	    jack_callback_buffer[j]=jack_input_volume[i]*
+	      jack_input_buffer[i][1][j];
+	    break;
+	  case 2: // L only
+	    jack_callback_buffer[j]=jack_input_volume[i]*
+	      jack_input_buffer[i][0][j];
+	    break;
+	  case 1: // swap, sum R+L
+	  case 0: // normal, sum L+R
+	  default:
+	    jack_callback_buffer[j]=jack_input_volume[i]*
+	      (jack_input_buffer[i][0][j]+jack_input_buffer[i][1][j]);
+	    break;
+	  }
+	} // for nframes
+	n=jack_record_ring[i]->
+	  write((char *)jack_callback_buffer,
+		nframes*sizeof(jack_default_audio_sample_t))/
+	  sizeof(jack_default_audio_sample_t);
+	break;
 
-          case 2: // stereo
-            for(unsigned j=0;j<nframes;j++) {
-              switch(jack_input_mode[jack_card_process][i]) {
-                  case 3: // R only
-                    memset(&jack_callback_buffer[2*j],0,sizeof(jack_input_buffer[i][0][j]));
-                    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
-                      jack_input_buffer[i][1][j];
-                    break;
-                  case 2: // L only
-                    jack_callback_buffer[2*j]=jack_input_volume[i]*
-                      jack_input_buffer[i][0][j];
-                    memset(&jack_callback_buffer[2*j+1],0,sizeof(jack_input_buffer[i][1][j]));
-                    break;
-                  case 1: // swap
-                    jack_callback_buffer[2*j]=jack_input_volume[i]*
-                      jack_input_buffer[i][1][j];
-                    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
-                      jack_input_buffer[i][0][j];
-                    break;
-                  case 0: // normal
-                  default:
-                    jack_callback_buffer[2*j]=jack_input_volume[i]*
-                      jack_input_buffer[i][0][j];
-                    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
-                      jack_input_buffer[i][1][j];
-                    break;
-              }
-            } // for nframes
-            n=jack_record_ring[i]->
-              write((char *)jack_callback_buffer,
-                    2*nframes*sizeof(jack_default_audio_sample_t))/
-                (2*sizeof(jack_default_audio_sample_t));
-            break;
+      case 2: // stereo
+	for(unsigned j=0;j<nframes;j++) {
+	  switch(jack_input_mode[jack_card_process][i]) {
+	  case 3: // R only
+	    memset(&jack_callback_buffer[2*j],0,
+		   sizeof(jack_input_buffer[i][0][j]));
+	    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
+	      jack_input_buffer[i][1][j];
+	    break;
+	  case 2: // L only
+	    jack_callback_buffer[2*j]=jack_input_volume[i]*
+	      jack_input_buffer[i][0][j];
+	    memset(&jack_callback_buffer[2*j+1],0,
+		   sizeof(jack_input_buffer[i][1][j]));
+	    break;
+	  case 1: // swap
+	    jack_callback_buffer[2*j]=jack_input_volume[i]*
+	      jack_input_buffer[i][1][j];
+	    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
+	      jack_input_buffer[i][0][j];
+	    break;
+	  case 0: // normal
+	  default:
+	    jack_callback_buffer[2*j]=jack_input_volume[i]*
+	      jack_input_buffer[i][0][j];
+	    jack_callback_buffer[2*j+1]=jack_input_volume[i]*
+	      jack_input_buffer[i][1][j];
+	    break;
+	  }
+	} // for nframes
+	n=jack_record_ring[i]->
+	  write((char *)jack_callback_buffer,
+		2*nframes*sizeof(jack_default_audio_sample_t))/
+	  (2*sizeof(jack_default_audio_sample_t));
+	break;
       }
     }
   }
@@ -193,52 +197,69 @@ int JackProcess(jack_nframes_t nframes, void *arg)
   for(int i=0;i<RD_MAX_STREAMS;i++) {
     if(jack_playing[i]) {
       switch(jack_output_channels[i]) {
-	  case 1:
-	    n=jack_play_ring[i]->
-	      read((char *)jack_callback_buffer,
-		   nframes*sizeof(jack_default_audio_sample_t))/
-	      sizeof(jack_default_audio_sample_t);
-	    break;
+      case 1:
+	n=jack_play_ring[i]->
+	  read((char *)jack_callback_buffer,
+	       nframes*sizeof(jack_default_audio_sample_t))/
+	  sizeof(jack_default_audio_sample_t);
+	stream_out_meter=0.0;
+	for(unsigned j=0;j<n;j++) {  // Stream Output Meters
+	  if(fabsf(jack_callback_buffer[j])>stream_out_meter) {
+	    stream_out_meter=fabsf(jack_callback_buffer[j]);
+	  }
+	}
+	jack_stream_output_meter[i][0]->addValue(stream_out_meter);
+	jack_stream_output_meter[i][1]->addValue(stream_out_meter);
+	break;
 
-	  case 2:
-	    n=jack_play_ring[i]->
-	      read((char *)jack_callback_buffer,
-		   2*nframes*sizeof(jack_default_audio_sample_t))/
-	      (2*sizeof(jack_default_audio_sample_t));
-	    break;
+      case 2:
+	n=jack_play_ring[i]->
+	  read((char *)jack_callback_buffer,
+	       2*nframes*sizeof(jack_default_audio_sample_t))/
+	  (2*sizeof(jack_default_audio_sample_t));
+	for(unsigned j=0;j<2;j++) {  // Stream Output Meters
+	  stream_out_meter=0.0;
+	  for(unsigned k=0;k<n;k+=2) {
+	    if(fabsf(jack_callback_buffer[k+j])>stream_out_meter) {
+	      stream_out_meter=fabsf(jack_callback_buffer[k+j]);
+	    }
+	  }
+	  jack_stream_output_meter[i][j]->addValue(stream_out_meter);
+	}
+	break;
       }
       for(int j=0;j<RD_MAX_PORTS;j++) {
 	if(jack_output_volume[j][i]>0.0) {
 	  switch(jack_output_channels[i]) {
-	      case 1:
-		for(unsigned k=0;k<n;k++) {
-		  jack_output_buffer[j][0][k]=
-		    jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
-		    jack_callback_buffer[k];
-		  jack_output_buffer[j][1][k]=
-		    jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
-		    jack_callback_buffer[k];
-		}
-		if(n!=nframes && jack_eof[i]) {
-		  jack_stopping[i]=true;
-		  jack_playing[i]=false;
-		}
-		break;
+	  case 1:
+	    for(unsigned k=0;k<n;k++) {
+	      jack_output_buffer[j][0][k]=
+		jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
+		jack_callback_buffer[k];
+	      jack_output_buffer[j][1][k]=
+		jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
+		jack_callback_buffer[k];
+	    }
+	    if(n!=nframes && jack_eof[i]) {
+	      jack_stopping[i]=true;
+	      jack_playing[i]=false;
+	    }
+	    break;
 
-	      case 2:
-		for(unsigned k=0;k<n;k++) {
-		  jack_output_buffer[j][0][k]=
-		    jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
-		    jack_callback_buffer[k*2];
-		  jack_output_buffer[j][1][k]=
-		    jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
-		    jack_callback_buffer[k*2+1];
-		}
-		if(n!=nframes && jack_eof[i]) {
-		  jack_stopping[i]=true;
-		  jack_playing[i]=false;
-		}
-		break;
+	  case 2:
+	    for(unsigned k=0;k<n;k++) {
+	      jack_output_buffer[j][0][k]=
+		jack_output_buffer[j][0][k]+jack_output_volume[j][i]*
+		jack_callback_buffer[k*2];
+	      jack_output_buffer[j][1][k]=
+		jack_output_buffer[j][1][k]+jack_output_volume[j][i]*
+		jack_callback_buffer[k*2+1];
+	    }
+	    if(n!=nframes && jack_eof[i]) {
+	      jack_stopping[i]=true;
+	      jack_playing[i]=false;
+	    }
+	    break;
 	  }
 	}
       }
@@ -256,27 +277,27 @@ int JackProcess(jack_nframes_t nframes, void *arg)
     in_meter[1]=0.0;
     for(unsigned k=0;k<nframes;k++) {
       switch(jack_input_mode[jack_card_process][i]) {
-          case 3: // R only
-            if(jack_input_buffer[i][1][k]>in_meter[1]) 
-              in_meter[1]=jack_input_buffer[i][1][k];
-            break;
-          case 2: // L only
-            if(jack_input_buffer[i][0][k]>in_meter[0]) 
-              in_meter[0]=jack_input_buffer[i][0][k];
-            break;
-          case 1: // swap
-            if(jack_input_buffer[i][0][k]>in_meter[1]) 
-              in_meter[1]=jack_input_buffer[i][0][k];
-            if(jack_input_buffer[i][1][k]>in_meter[0]) 
-              in_meter[0]=jack_input_buffer[i][1][k];
-            break;
-          case 0: // normal
-          default:
-            if(jack_input_buffer[i][0][k]>in_meter[0]) 
-              in_meter[0]=jack_input_buffer[i][0][k];
-            if(jack_input_buffer[i][1][k]>in_meter[1]) 
-              in_meter[1]=jack_input_buffer[i][1][k];
-            break;
+      case 3: // R only
+	if(jack_input_buffer[i][1][k]>in_meter[1]) 
+	  in_meter[1]=jack_input_buffer[i][1][k];
+	break;
+      case 2: // L only
+	if(jack_input_buffer[i][0][k]>in_meter[0]) 
+	  in_meter[0]=jack_input_buffer[i][0][k];
+	break;
+      case 1: // swap
+	if(jack_input_buffer[i][0][k]>in_meter[1]) 
+	  in_meter[1]=jack_input_buffer[i][0][k];
+	if(jack_input_buffer[i][1][k]>in_meter[0]) 
+	  in_meter[0]=jack_input_buffer[i][1][k];
+	break;
+      case 0: // normal
+      default:
+	if(jack_input_buffer[i][0][k]>in_meter[0]) 
+	  in_meter[0]=jack_input_buffer[i][0][k];
+	if(jack_input_buffer[i][1][k]>in_meter[1]) 
+	  in_meter[1]=jack_input_buffer[i][1][k];
+	break;
       }
     } // for nframes
     jack_input_meter[i][0]->addValue(in_meter[0]);
@@ -342,6 +363,9 @@ void JackInitCallback()
   for(int i=0;i<RD_MAX_STREAMS;i++) {
     jack_play_ring[i]=NULL;
     jack_playing[i]=false;
+    for(int j=0;j<2;j++) {
+      jack_stream_output_meter[i][j]=new RDMeterAverage(avg_periods);
+    }
   }
 }
 #endif  // JACK
@@ -393,6 +417,12 @@ void MainObject::jackRecordTimerData(int stream)
 void MainObject::jackInit(RDStation *station)
 {
 #ifdef JACK
+  QString sql;
+  RDSqlQuery *q;
+  jack_options_t jackopts=JackNullOption;
+  jack_status_t jackstat=JackFailure;
+  RDConfig::LogPriority prio=RDConfig::LogDebug;
+
   jack_connected=false;
   jack_activated=false;
 
@@ -410,19 +440,124 @@ void MainObject::jackInit(RDStation *station)
   }
   QString name=QString().sprintf("rivendell_%d",jack_card);
 
+  //
+  // Start Jack Server
+  //
+  if(station->startJack()) {
+    QStringList fields=QStringList().split(" ",station->jackCommandLine());
+    QProcess *proc=new QProcess(fields,this);
+    if(proc->start()) {
+      LogLine(RDConfig::LogDebug,"JACK server started");
+    }
+    else {
+      LogLine(RDConfig::LogErr,"failed to start JACK server");
+    }
+    sleep(1);
+  }
+
   //
   // Attempt to Connect to Jack Server
   //
+  jackopts=JackNoStartServer;
+  if(station->jackServerName().isEmpty()) {
+    jack_client=jack_client_open(name,jackopts,&jackstat);
+  }
+  else {
+    jack_client=jack_client_open(name,jackopts,&jackstat,
+				 (const char *)station->jackServerName());
+  }
+  if(jack_client==NULL) {
+    if((jackstat&JackInvalidOption)!=0) {
+      fprintf (stderr, "invalid or unsupported JACK option\n");
+      LogLine(prio,"invalid or unsupported JACK option");
+    }
 
-  if((jack_client=jack_client_new((const char *)name))==0) {
+    if((jackstat&JackServerError)!=0) {
+      fprintf (stderr, "communication error with the JACK server\n");
+      LogLine(prio,"communication error with the JACK server");
+    }
+
+    if((jackstat&JackNoSuchClient)!=0) {
+      fprintf (stderr, "requested JACK client does not exist\n");
+      LogLine(prio,"requested JACK client does not exist");
+    }
+
+    if((jackstat&JackLoadFailure)!=0) {
+      fprintf (stderr, "unable to load internal JACK client\n");
+      LogLine(prio,"unable to load internal JACK client");
+    }
+
+    if((jackstat&JackInitFailure)!=0) {
+      fprintf (stderr, "unable to initialize JACK client\n");
+      LogLine(prio,"unable to initialize JACK client");
+    }
+
+    if((jackstat&JackShmFailure)!=0) {
+      fprintf (stderr, "unable to access JACK shared memory\n");
+      LogLine(prio,"unable to access JACK shared memory");
+    }
+
+    if((jackstat&JackVersionError)!=0) {
+      fprintf (stderr, "JACK protocol version mismatch\n");
+      LogLine(prio,"JACK protocol version mismatch");
+    }
+
+    if((jackstat&JackServerStarted)!=0) {
+      fprintf (stderr, "JACK server started\n");
+      LogLine(prio,"JACK server started");
+    }
+
+    if((jackstat&JackServerFailed)!=0) {
+      fprintf (stderr, "unable to communication with JACK server\n");
+      LogLine(prio,"unable to communicate with JACK server");
+    }
+
+    if((jackstat&JackNameNotUnique)!=0) {
+      fprintf (stderr, "JACK client name not unique\n");
+      LogLine(prio,"JACK client name not unique");
+    }
+
+    if((jackstat&JackFailure)!=0) {
+      fprintf (stderr, "JACK general failure\n");
+      LogLine(prio,"JACK general failure");
+    }
+    jack_card=-1;
     fprintf (stderr, "no connection to JACK server\n");
-    LogLine(RDConfig::LogNotice,"no connection to JACK server");
+    LogLine(prio,"no connection to JACK server");
     return;
   }
   jack_connected=true;
   jack_set_process_callback(jack_client,JackProcess,0);
   jack_set_sample_rate_callback(jack_client,JackSampleRate,0);
+  //jack_set_port_connect_callback(jack_client,JackPortConnectCB,this);
+#ifdef HAVE_JACK_INFO_SHUTDOWN
+  jack_on_info_shutdown(jack_client,JackInfoShutdown,0);
+#else
   jack_on_shutdown(jack_client,JackShutdown,0);
+#endif  // HAVE_JACK_INFO_SHUTDOWN
+  LogLine(RDConfig::LogDebug,"connected to JACK server");
+
+  //
+  // Start JACK Clients
+  //
+  sql=QString("select DESCRIPTION,COMMAND_LINE from JACK_CLIENTS where ")+
+    "STATION_NAME=\""+RDEscapeString(station->name())+"\"";
+  q=new RDSqlQuery(sql);
+  while(q->next()) {
+    QStringList fields=QStringList().split(" ",q->value(1).toString());
+    jack_clients.push_back(new QProcess(fields,this));
+    if(jack_clients.back()->start()) {
+      LogLine(RDConfig::LogDebug,"started JACK Client \""+
+	      q->value(0).toString()+"\"");
+    }
+    else {
+      LogLine(RDConfig::LogWarning,"failed to start JACK Client \""+
+	      q->value(0).toString()+"\" ["+
+	      q->value(1).toString()+"]");
+    }
+    sleep(1);
+  }
+  delete q;
 
   //
   // Tell the database about us
@@ -439,8 +574,10 @@ void MainObject::jackInit(RDStation *station)
   //
   for(int i=0;i<RD_MAX_STREAMS;i++) {
     for(int j=0;j<RD_MAX_PORTS;j++) {
-      jack_output_volume_db[j][i]=0;
+      jack_output_volume_db[j][i]=0; 
+      jack_samples_recorded[i]=0;
     }
+    jack_st_conv[i]=NULL;
   }
   for(int i=0;i<RD_MAX_PORTS;i++) {
     jack_input_volume_db[i]=0;
@@ -458,11 +595,11 @@ void MainObject::jackInit(RDStation *station)
   //
   // Stop & Fade Timers
   //
-  QSignalMapper *stop_mapper=new QSignalMapper(this,"stop_mapper");
+  QSignalMapper *stop_mapper=new QSignalMapper(this);
   connect(stop_mapper,SIGNAL(mapped(int)),this,SLOT(jackStopTimerData(int)));
-  QSignalMapper *fade_mapper=new QSignalMapper(this,"fade_mapper");
+  QSignalMapper *fade_mapper=new QSignalMapper(this);
   connect(fade_mapper,SIGNAL(mapped(int)),this,SLOT(jackFadeTimerData(int)));
-  QSignalMapper *record_mapper=new QSignalMapper(this,"record_mapper");
+  QSignalMapper *record_mapper=new QSignalMapper(this);
   connect(record_mapper,SIGNAL(mapped(int)),
 	  this,SLOT(jackRecordTimerData(int)));
   for(int i=0;i<RD_MAX_STREAMS;i++) {
@@ -510,8 +647,9 @@ void MainObject::jackInit(RDStation *station)
   //
   JackInitCallback();
   jack_wave_buffer=new short[RINGBUFFER_SIZE];
+  jack_wave32_buffer=new int[RINGBUFFER_SIZE];
+  jack_wave24_buffer=new uint8_t[RINGBUFFER_SIZE];
   jack_sample_buffer=new jack_default_audio_sample_t[RINGBUFFER_SIZE];
-  jack_resample_buffer=new jack_default_audio_sample_t[2*RINGBUFFER_SIZE];
 
   //
   // Join the Graph
@@ -520,6 +658,10 @@ void MainObject::jackInit(RDStation *station)
     return;
   }
   jack_sample_rate=jack_get_sample_rate(jack_client);
+  if(jack_sample_rate!=system_sample_rate) {
+    fprintf (stderr,"JACK sample rate mismatch!\n");
+    LogLine(RDConfig::LogWarning,"JACK sample rate mismatch!");
+  }
   jack_activated=true;
   cae_driver[jack_card]=RDStation::Jack;
   JackSessionSetup();
@@ -531,6 +673,11 @@ void MainObject::jackInit(RDStation *station)
 void MainObject::jackFree()
 {
 #ifdef JACK
+  for(unsigned i=0;i<jack_clients.size();i++) {
+    jack_clients[i]->kill();
+    delete jack_clients[i];
+  }
+  jack_clients.clear();
   if(jack_activated) {
     jack_deactivate(jack_client);
   }
@@ -559,13 +706,22 @@ bool MainObject::jackLoadPlayback(int card,QString wavename,int *stream)
     *stream=-1;
     return false;
   }
-  if((jack_play_wave[*stream]->getFormatTag()!=WAVE_FORMAT_PCM)||
-     (jack_play_wave[*stream]->getBitsPerSample()!=16)) {
-    LogLine(RDConfig::LogNotice,QString().sprintf(
-            "Error: jackLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
-            (const char *) wavename,
-            jack_play_wave[*stream]->getFormatTag(),
-            jack_play_wave[*stream]->getBitsPerSample() ));
+  switch(jack_play_wave[*stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+  case WAVE_FORMAT_VORBIS:
+    break;
+
+  case WAVE_FORMAT_MPEG:
+    InitMadDecoder(card,*stream,jack_play_wave[*stream]);
+    break;
+
+  default:
+    LogLine(RDConfig::LogNotice,
+	    QString().sprintf(
+	    "Error: jackLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
+	    (const char *) wavename,
+	    jack_play_wave[*stream]->getFormatTag(),
+	    jack_play_wave[*stream]->getBitsPerSample() ));
     delete jack_play_wave[*stream];
     jack_play_wave[*stream]=NULL;
     FreeJackOutputStream(*stream);
@@ -596,6 +752,11 @@ bool MainObject::jackUnloadPlayback(int card,int stream)
     return false;
   }
   jack_playing[stream]=false;
+  switch(jack_play_wave[stream]->getFormatTag()) {
+  case WAVE_FORMAT_MPEG:
+    FreeMadDecoder(card,stream);
+    break;
+  }
   jack_play_wave[stream]->closeWave();
   delete jack_play_wave[stream];
   jack_play_wave[stream]=NULL;
@@ -610,25 +771,46 @@ bool MainObject::jackUnloadPlayback(int card,int stream)
 bool MainObject::jackPlaybackPosition(int card,int stream,unsigned pos)
 {
 #ifdef JACK
+  unsigned offset=0;
+
   if ((stream <0) || (stream >= RD_MAX_STREAMS)){
     return false;
   }
-  if(jack_playing[stream]) {
-  }
   jack_eof[stream]=false;
   jack_play_ring[stream]->reset();
-  unsigned offset=
-    (unsigned)((double)jack_play_wave[stream]->getSamplesPerSec()*
-	       (double)jack_play_wave[stream]->getBlockAlign()*
-	       (double)pos/1000);
-  jack_offset[stream]=offset/jack_play_wave[stream]->getBlockAlign();
-  offset=jack_offset[stream]*jack_play_wave[stream]->getBlockAlign();
+
+
+  switch(jack_play_wave[stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+  case WAVE_FORMAT_VORBIS:
+    offset=(unsigned)((double)jack_play_wave[stream]->getSamplesPerSec()*
+		      (double)jack_play_wave[stream]->getBlockAlign()*
+		      (double)pos/1000);
+    jack_offset[stream]=offset/jack_play_wave[stream]->getBlockAlign();
+    offset=jack_offset[stream]*jack_play_wave[stream]->getBlockAlign();
+    break;
+
+  case WAVE_FORMAT_MPEG:
+    offset=(unsigned)((double)jack_play_wave[stream]->getSamplesPerSec()*
+		      (double)pos/1000);
+    jack_offset[stream]=offset/1152*1152;
+    offset=jack_offset[stream]/1152*jack_play_wave[stream]->getBlockAlign();
+    FreeMadDecoder(jack_card,stream);
+    InitMadDecoder(jack_card,stream,jack_play_wave[stream]);
+    break;
+  }
   if(jack_offset[stream]>(int)jack_play_wave[stream]->getSampleLength()) {
     return false;
   }
   jack_output_pos[stream]=0;
   jack_play_wave[stream]->seekWave(offset,SEEK_SET);
   FillJackOutputStream(stream);
+
+  if(jack_playing[stream]) {
+    jack_stop_timer[stream]->stop();
+    jack_stop_timer[stream]->
+      start(jack_play_wave[stream]->getExtTimeLength()-pos,true);
+  }
   return true;
 #else
   return false;
@@ -641,10 +823,15 @@ bool MainObject::jackPlay(int card,int stream,int length,int speed,bool pitch,
 {
 #ifdef JACK
   if((stream <0) || (stream >= RD_MAX_STREAMS) || 
-     (jack_play_ring[stream]==NULL)||jack_playing[stream]||
-     (speed!=RD_TIMESCALE_DIVISOR)) {
+     (jack_play_ring[stream]==NULL)||jack_playing[stream]) {
     return false;
   }
+  if(speed!=RD_TIMESCALE_DIVISOR) {
+    jack_st_conv[stream]=new soundtouch::SoundTouch();
+    jack_st_conv[stream]->setTempo((float)speed/RD_TIMESCALE_DIVISOR);
+    jack_st_conv[stream]->setSampleRate(jack_output_sample_rate[stream]);
+    jack_st_conv[stream]->setChannels(jack_output_channels[stream]);
+  }
   jack_playing[stream]=true;
   if(length>0) {
     jack_stop_timer[stream]->start(length,true);
@@ -666,6 +853,7 @@ bool MainObject::jackStopPlayback(int card,int stream)
   }
   jack_playing[stream]=false;
   jack_stop_timer[stream]->stop();
+  statePlayUpdate(card,stream,2);
   return true;
 #else
   return false;
@@ -676,7 +864,7 @@ bool MainObject::jackStopPlayback(int card,int stream)
 bool MainObject::jackTimescaleSupported(int card)
 {
 #ifdef JACK
-  return false;
+  return true;
 #else
   return false;
 #endif  // JACK
@@ -687,10 +875,97 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
 			       int samprate,int bitrate,QString wavename)
 {
 #ifdef JACK
+  jack_record_wave[stream]=new RDWaveFile(wavename);
+  switch(coding) {
+  case 0:  // PCM16
+    jack_record_wave[stream]->setFormatTag(WAVE_FORMAT_PCM);
+    jack_record_wave[stream]->setChannels(chans);
+    jack_record_wave[stream]->setSamplesPerSec(samprate);
+    jack_record_wave[stream]->setBitsPerSample(16);
+    break;
+
+  case 4:  // PCM24
+    jack_record_wave[stream]->setFormatTag(WAVE_FORMAT_PCM);
+    jack_record_wave[stream]->setChannels(chans);
+    jack_record_wave[stream]->setSamplesPerSec(samprate);
+    jack_record_wave[stream]->setBitsPerSample(24);
+    break;
+
+  case 2:  // MPEG Layer 2
+    if(!InitTwoLameEncoder(card,stream,chans,samprate,bitrate)) {
+      delete jack_record_wave[stream];
+      jack_record_wave[stream]=NULL;
+      return false;
+    }
+    jack_record_wave[stream]->setFormatTag(WAVE_FORMAT_MPEG);
+    jack_record_wave[stream]->setChannels(chans);
+    jack_record_wave[stream]->setSamplesPerSec(samprate);
+    jack_record_wave[stream]->setBitsPerSample(16);
+    jack_record_wave[stream]->setHeadLayer(ACM_MPEG_LAYER2);
+    switch(chans) {
+    case 1:
+      jack_record_wave[stream]->setHeadMode(ACM_MPEG_SINGLECHANNEL);
+      break;
+
+    case 2:
+      jack_record_wave[stream]->setHeadMode(ACM_MPEG_STEREO);
+      break;
+
+    default:
+      LogLine(RDConfig::LogErr,QString().
+	sprintf("requested unsupported channel count %d, card: %d, stream: %d",
+		chans,card,stream));
+      delete jack_record_wave[stream];
+      jack_record_wave[stream]=NULL;
+      return false;
+    }
+    jack_record_wave[stream]->setHeadBitRate(bitrate);
+    jack_record_wave[stream]->setMextChunk(true);
+    jack_record_wave[stream]->setMextHomogenous(true);
+    jack_record_wave[stream]->setMextPaddingUsed(false);
+    jack_record_wave[stream]->setMextHackedBitRate(true);
+    jack_record_wave[stream]->setMextFreeFormat(false);
+    jack_record_wave[stream]->
+      setMextFrameSize(144*jack_record_wave[stream]->getHeadBitRate()/
+		       jack_record_wave[stream]->getSamplesPerSec());
+    jack_record_wave[stream]->setMextAncillaryLength(5);
+    jack_record_wave[stream]->setMextLeftEnergyPresent(true);
+    if(chans>1) {
+      jack_record_wave[stream]->setMextRightEnergyPresent(true);
+    }
+    else {
+      jack_record_wave[stream]->setMextRightEnergyPresent(false);
+    }
+    jack_record_wave[stream]->setMextPrivateDataPresent(false);
+    break;
+
+  default:
+    LogLine(RDConfig::LogErr,QString().
+	    sprintf("requested invalid audio encoding %d, card: %d, stream: %d",
+		    coding,card,stream));
+    delete jack_record_wave[stream];
+    jack_record_wave[stream]=NULL;
+    return false;
+  }
+  jack_record_wave[stream]->setBextChunk(true);
+  jack_record_wave[stream]->setLevlChunk(true);
+  if(!jack_record_wave[stream]->createWave()) {
+    delete jack_record_wave[stream];
+    jack_record_wave[stream]=NULL;
+    return false;
+  }
+  chown((const char *)wavename,rd_config->uid(),rd_config->gid());
+  jack_input_channels[stream]=chans;
+  jack_record_ring[stream]=new RDRingBuffer(RINGBUFFER_SIZE);
+  jack_record_ring[stream]->reset();
+  jack_ready[stream]=true;
+  return true;
+
+  /*
   if ((stream <0) || (stream >=RD_MAX_PORTS)){
     return false;
   }
-  jack_record_wave[stream]=new RDWaveFile(wavename);
+    jack_record_wave[stream]=new RDWaveFile(wavename);
   jack_record_wave[stream]->setFormatTag(WAVE_FORMAT_PCM);
   jack_record_wave[stream]->setChannels(chans);
   jack_record_wave[stream]->setSamplesPerSec(samprate);
@@ -708,13 +983,14 @@ bool MainObject::jackLoadRecord(int card,int stream,int coding,int chans,
   jack_record_ring[stream]->reset();
   jack_ready[stream]=true;
   return true;
+  */
 #else
   return false;
 #endif  // JACK
 }
 
 
-bool MainObject::jackUnloadRecord(int card,int stream)
+bool MainObject::jackUnloadRecord(int card,int stream,unsigned *len)
 {
 #ifdef JACK
   if ((stream <0) || (stream >= RD_MAX_PORTS)){
@@ -722,12 +998,15 @@ bool MainObject::jackUnloadRecord(int card,int stream)
   }
   jack_recording[stream]=false;
   jack_ready[stream]=false;
-  EmptyJackInputStream(stream);
-  jack_record_wave[stream]->closeWave();
+  EmptyJackInputStream(stream,true);
+  *len=jack_samples_recorded[stream];
+  jack_samples_recorded[stream]=0;
+  jack_record_wave[stream]->closeWave(*len);
   delete jack_record_wave[stream];
   jack_record_wave[stream]=NULL;
   delete jack_record_ring[stream];
   jack_record_ring[stream]=NULL;
+  FreeTwoLameEncoder(card,stream);
   return true;
 #else
   return false;
@@ -975,13 +1254,44 @@ bool MainObject::jackGetOutputMeters(int card,int port,short levels[2])
 }
 
 
+bool MainObject::jackGetStreamOutputMeters(int card,int stream,short levels[2])
+{
+#ifdef JACK
+  jack_default_audio_sample_t meter;
+  if ((stream<0) || (stream>=RD_MAX_STREAMS)){
+    return false;
+  }
+
+  for(int i=0;i<2;i++) {
+    meter=jack_stream_output_meter[stream][i]->average();
+    if(meter==0.0) {
+      levels[i]=-10000;
+    }
+    else {
+      levels[i]=(short)(2000.0*log10(meter));
+      if(levels[i]<-10000) {
+	levels[i]=-10000;
+      }
+    }
+  }
+  return true;
+#else
+  return false;
+#endif  // JACK
+}
+
+
 void MainObject::jackGetOutputPosition(int card,unsigned *pos)
 {
 #ifdef JACK
   for(int i=0;i<RD_MAX_STREAMS;i++) {
-//    pos[i]=(((unsigned long long)jack_offset[i]+jack_output_pos[i])*1000)/
-//	    jack_sample_rate;
-    pos[i]=((unsigned long long)jack_offset[i]+jack_output_pos[i]);
+    if(jack_play_wave[i]!=NULL) {
+      pos[i]=1000*((unsigned long long)jack_offset[i]+jack_output_pos[i])/
+	jack_play_wave[i]->getSamplesPerSec();
+    }
+    else {
+      pos[i]=0;
+    }
   }
 #endif  // JACK
 }
@@ -1010,6 +1320,28 @@ bool MainObject::jackSetPassthroughLevel(int card,int in_port,int out_port,
 }
 
 
+void MainObject::jackConnectPorts(const QString &out,const QString &in)
+{
+#ifdef JACK
+  if(jack_card<0) {
+    return;
+  }
+  jack_connect(jack_client,(const char *)in,(const char *)out);  
+#endif  // JACK
+}
+
+
+void MainObject::jackDisconnectPorts(const QString &out,const QString &in)
+{
+#ifdef JACK
+  if(jack_card<0) {
+    return;
+  }
+  jack_disconnect(jack_client,(const char *)in,(const char *)out);  
+#endif  // JACK
+}
+
+
 int MainObject::GetJackOutputStream()
 {
 #ifdef JACK
@@ -1034,55 +1366,103 @@ void MainObject::FreeJackOutputStream(int stream)
   }
   delete jack_play_ring[stream];
   jack_play_ring[stream]=NULL;
+  if(jack_st_conv[stream]!=NULL) {
+    delete jack_st_conv[stream];
+    jack_st_conv[stream]=NULL;
+  }
 #else
   return;
 #endif
 }
 
 
-void MainObject::EmptyJackInputStream(int stream)
+void MainObject::EmptyJackInputStream(int stream,bool done)
 {
 #ifdef JACK
   if ((stream <0) || (stream >= RD_MAX_STREAMS)){
     return;
   }
-  int n=jack_record_ring[stream]->
-    read((char *)jack_sample_buffer,RINGBUFFER_SIZE)/
-    sizeof(jack_default_audio_sample_t);
-  if(n==0) {
-    return;
-  }
-  if(jack_record_wave[stream]->getSamplesPerSec()!=jack_sample_rate) {
-    double ratio=(double)jack_record_wave[stream]->getSamplesPerSec()/
-      (double)jack_sample_rate;
-    n=Resample(jack_sample_buffer,jack_resample_buffer,
-	       n/jack_input_channels[stream],ratio,
-	       jack_input_channels[stream])*jack_input_channels[stream];
-#ifdef HAVE_SRC_CONV
-    src_float_to_short_array(jack_resample_buffer,jack_wave_buffer,n);
-#else
-    for(int i=0;i<n;i++) {
-      jack_wave_buffer[i]=(short)(jack_sample_buffer[i]*32768.0);
-    }
-#endif  // HAVE_SRC_CONV
-  }
-  else {
-#ifdef HAVE_SRC_CONV
-    src_float_to_short_array(jack_sample_buffer,jack_wave_buffer,n);
-#else
-    for(int i=0;i<n;i++) {
-      jack_wave_buffer[i]=(short)(jack_sample_buffer[i]*32768.0);
-    }
-#endif  // HAVE_SRC_CONV
-  }
-  jack_record_wave[stream]->writeWave(jack_wave_buffer,n*sizeof(short));
+  unsigned n=jack_record_ring[stream]->
+    read((char *)jack_sample_buffer,jack_record_ring[stream]->readSpace());
+  WriteJackBuffer(stream,jack_sample_buffer,n,done);
 #endif  // JACK
 }
 
+#ifdef JACK
+void MainObject::WriteJackBuffer(int stream,jack_default_audio_sample_t *buffer,
+				 unsigned len,bool done)
+{
+  ssize_t s;
+  unsigned char mpeg[2048];
+  unsigned frames;
+  unsigned n;
+
+  frames=len/(sizeof(jack_default_audio_sample_t)*
+	      jack_record_wave[stream]->getChannels());
+  jack_samples_recorded[stream]+=frames;
+  switch(jack_record_wave[stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+    switch(jack_record_wave[stream]->getBitsPerSample()) {
+    case 16:  // PCM16
+      n=len/sizeof(jack_default_audio_sample_t);
+      src_float_to_short_array(buffer,jack_wave_buffer,n);
+      jack_record_wave[stream]->writeWave(jack_wave_buffer,n*sizeof(short));
+      break;
+
+    case 24:  // PCM24
+      n=len/sizeof(jack_default_audio_sample_t);
+      src_float_to_int_array(buffer,jack_wave32_buffer,n);
+      for(unsigned i=0;i<n;i++) {
+	for(unsigned j=0;j<3;j++) {
+	  jack_wave24_buffer[3*i+j]=((uint8_t *)jack_wave32_buffer)[4*i+j+1];
+	}
+      }
+      jack_record_wave[stream]->writeWave(jack_wave24_buffer,n*3);
+      break;
+    }
+    break;
+
+  case WAVE_FORMAT_MPEG:
+#ifdef HAVE_TWOLAME
+    for(unsigned i=0;i<frames;i+=1152) {
+      if((i+1152)>frames) {
+	n=frames-i;
+      }
+      else {
+	n=1152;
+      }
+      if((s=twolame_encode_buffer_float32_interleaved(
+		 twolame_lameopts[jack_card][stream],
+		 buffer+i*jack_record_wave[stream]->getChannels(),
+		 n,mpeg,2048))>=0) {
+	jack_record_wave[stream]->writeWave(mpeg,s);
+      }
+      else {
+	LogLine(RDConfig::LogErr,QString().
+	   sprintf("TwoLAME encode error, card: %d, stream: %d",jack_card,
+		   stream));
+      }
+    }
+    if(done) {
+      if((s=twolame_encode_flush(twolame_lameopts[jack_card][stream],
+				 mpeg,2048))>=0) {
+	jack_record_wave[stream]->writeWave(mpeg,s);
+      }
+    }
+#endif  // HAVE_TWOLAME
+    break;
+  }
+}
+#endif  // JACK
 
 void MainObject::FillJackOutputStream(int stream)
 {
 #ifdef JACK
+  int n=0;
+  unsigned mpeg_frames=0;
+  unsigned frame_offset=0;
+  int m=0;
+
   if ((stream <0) || (stream >= RD_MAX_STREAMS)){
     return;
   }
@@ -1091,36 +1471,138 @@ void MainObject::FillJackOutputStream(int stream)
   if((free<=0)||(jack_eof[stream]==true)) {
     return;
   }
-  double ratio=(double)jack_sample_rate/
-    (double)jack_play_wave[stream]->getSamplesPerSec();
-  free=(int)((double)free/ratio)/jack_output_channels[stream]*
-    jack_output_channels[stream];
-  int n=jack_play_wave[stream]->readWave(jack_wave_buffer,sizeof(short)*free)/
-    sizeof(short);
-  if(n!=free) {
-    jack_eof[stream]=true;
-    jack_stop_timer[stream]->stop();
+  switch(jack_play_wave[stream]->getFormatTag()) {
+  case WAVE_FORMAT_PCM:
+    switch(jack_play_wave[stream]->getBitsPerSample()) {
+    case 16:  // PMC16
+      free=(int)free/jack_output_channels[stream]*jack_output_channels[stream];
+      n=jack_play_wave[stream]->readWave(jack_wave_buffer,sizeof(short)*free)/
+	sizeof(short);
+      if((n!=free)&&(jack_st_conv[stream]==NULL)) {
+	jack_eof[stream]=true;
+	jack_stop_timer[stream]->stop();
+      }
+      src_short_to_float_array(jack_wave_buffer,jack_sample_buffer,n);
+      break;
+
+    case 24:  // PMC24
+      free=(int)free/jack_output_channels[stream]*jack_output_channels[stream];
+      n=jack_play_wave[stream]->readWave(jack_wave24_buffer,3*free)/3;
+      if((n!=free)&&(jack_st_conv[stream]==NULL)) {
+	jack_eof[stream]=true;
+	jack_stop_timer[stream]->stop();
+      }
+      for(int i=0;i<n;i++) {
+	for(unsigned j=0;j<3;j++) {
+	  ((uint8_t *)jack_wave32_buffer)[4*i+j+1]=jack_wave24_buffer[3*i+j];
+	}
+      }
+      src_int_to_float_array(jack_wave32_buffer,jack_sample_buffer,n);
+      break;
+    }
+    break;
+
+  case WAVE_FORMAT_VORBIS:
+    free=(int)free/jack_output_channels[stream]*jack_output_channels[stream];
+    n=jack_play_wave[stream]->readWave(jack_wave_buffer,sizeof(short)*free)/
+      sizeof(short);
+    if((n!=free)&&(jack_st_conv[stream]==NULL)) {
+      jack_eof[stream]=true;
+      jack_stop_timer[stream]->stop();
+    }
+    src_short_to_float_array(jack_wave_buffer,jack_sample_buffer,n);
+    break;
+
+  case WAVE_FORMAT_MPEG:
+#ifdef HAVE_MAD
+    mpeg_frames=free/(1152*jack_output_channels[stream]);
+    free=mpeg_frames*1152*jack_output_channels[stream];
+    for(unsigned i=0;i<mpeg_frames;i++) {
+      m=jack_play_wave[stream]->
+	readWave(mad_mpeg[jack_card][stream]+mad_left_over[jack_card][stream],
+		 mad_frame_size[jack_card][stream]);
+      if(m==mad_frame_size[jack_card][stream]) {
+	mad_stream_buffer(&mad_stream[jack_card][stream],
+			  mad_mpeg[jack_card][stream],
+			  m+mad_left_over[jack_card][stream]);
+	while(mad_frame_decode(&mad_frame[jack_card][stream],
+			    &mad_stream[jack_card][stream])==0) {
+	  mad_synth_frame(&mad_synth[jack_card][stream],
+			  &mad_frame[jack_card][stream]);
+	  n+=(jack_output_channels[stream]*
+	      mad_synth[jack_card][stream].pcm.length);
+	  for(int j=0;j<mad_synth[jack_card][stream].pcm.length;j++) {
+	    for(int k=0;k<mad_synth[jack_card][stream].pcm.channels;k++) {
+	      jack_sample_buffer[frame_offset+
+				 j*mad_synth[jack_card][stream].pcm.channels+k]=
+		(jack_default_audio_sample_t)
+		mad_f_todouble(mad_synth[jack_card][stream].pcm.samples[k][j]);
+	      
+	    }
+	  }
+	  frame_offset+=(mad_synth[jack_card][stream].pcm.length*
+			 mad_synth[jack_card][stream].pcm.channels);
+	}
+      }
+      else {  // End-of-file, read out last samples
+	memset(mad_mpeg[jack_card][stream]+mad_left_over[jack_card][stream],0,
+	       MAD_BUFFER_GUARD);
+	mad_stream_buffer(&mad_stream[jack_card][stream],
+			  mad_mpeg[jack_card][stream],
+			  MAD_BUFFER_GUARD+mad_left_over[jack_card][stream]);
+	if(mad_frame_decode(&mad_frame[jack_card][stream],
+			    &mad_stream[jack_card][stream])==0) {
+	  mad_synth_frame(&mad_synth[jack_card][stream],
+			  &mad_frame[jack_card][stream]);
+	  n+=(jack_output_channels[stream]*
+	      mad_synth[jack_card][stream].pcm.length);
+	  for(int j=0;j<mad_synth[jack_card][stream].pcm.length;j++) {
+	    for(int k=0;k<mad_synth[jack_card][stream].pcm.channels;k++) {
+	      jack_sample_buffer[frame_offset+
+				 j*mad_synth[jack_card][stream].pcm.channels+k]=
+		(jack_default_audio_sample_t)
+		mad_f_todouble(mad_synth[jack_card][stream].pcm.samples[k][j]);
+	    }
+	  }
+	}
+	jack_eof[stream]=true;
+	jack_stop_timer[stream]->stop();
+	continue;
+      }
+      mad_left_over[jack_card][stream]=
+	mad_stream[jack_card][stream].bufend-
+	mad_stream[jack_card][stream].next_frame;
+      memmove(mad_mpeg[jack_card][stream],
+	      mad_stream[jack_card][stream].next_frame,
+	      mad_left_over[jack_card][stream]);
+    }
+#endif  // HAVE_MAD
+    break;
   }
-#ifdef HAVE_SRC_CONV
-  src_short_to_float_array(jack_wave_buffer,jack_sample_buffer,n);
-#else
-  for(int i=0;i<n;i++) {
-    jack_sample_buffer[i]=
-      ((jack_default_audio_sample_t)(jack_wave_buffer[i]))/32768.0;
-  }
-#endif  // HAVE_SRC_CONV
-  if(jack_play_wave[stream]->getSamplesPerSec()!=jack_sample_rate) {
-    n=Resample(jack_sample_buffer,jack_resample_buffer,
-	       n/jack_output_channels[stream],ratio,
-	       jack_output_channels[stream])*jack_output_channels[stream];
-    jack_play_ring[stream]->
-      write((char *)jack_resample_buffer,
-	    n*sizeof(jack_default_audio_sample_t));
-  }
-  else {
+  if(jack_st_conv[stream]==NULL) {
     jack_play_ring[stream]->
       write((char *)jack_sample_buffer,n*sizeof(jack_default_audio_sample_t));
   }
+  else {
+    jack_st_conv[stream]->
+      putSamples(jack_sample_buffer,n/jack_output_channels[stream]);
+    free=jack_play_ring[stream]->writeSpace()/
+      (sizeof(jack_default_audio_sample_t)*jack_output_channels[stream])-1;
+    while((n=jack_st_conv[stream]->
+	   receiveSamples(jack_sample_buffer,free))>0) {
+      jack_play_ring[stream]->
+	write((char *)jack_sample_buffer,n*
+	      sizeof(jack_default_audio_sample_t)*
+	      jack_output_channels[stream]);
+      free=jack_play_ring[stream]->writeSpace()/
+	(sizeof(jack_default_audio_sample_t)*jack_output_channels[stream])-1;
+    }
+    if((jack_st_conv[stream]->numSamples()==0)&&
+       (jack_st_conv[stream]->numUnprocessedSamples()==0)) {
+      jack_eof[stream]=true;
+      jack_stop_timer[stream]->stop();
+    }
+  }
 #endif  // JACK
 }
 
@@ -1140,7 +1622,7 @@ void MainObject::JackClock()
   jack_clock_phase++;
   for(int i=0;i<RD_MAX_PORTS;i++) {
     if(jack_recording[i]) {
-      EmptyJackInputStream(i);
+      EmptyJackInputStream(i,false);
     }
   }
 #endif  // JACK
