@@ -4,10 +4,7 @@
 #
 # A shell utility for packaging Rivendell translation files.
 #
-# (C) Copyright 2005,2008 Fred Gleason <fredg@paravelsystems.com>
-#
-#      $Id: rdpack.sh,v 1.4 2008-04-01 18:27:24 fredg Exp $
-#      $Date: 2008-04-01 18:27:24 $
+# (C) Copyright 2005,2008,2016 Fred Gleason <fredg@paravelsystems.com>
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License version 2 as
@@ -36,7 +33,7 @@ LANG=`cat language`
 #
 # Package it
 #
-tar zvcf rivendell_$LANG-done.tar.gz $LANG/* > /dev/null
+tar zvcf rivendell_$LANG-done.tar.gz * > /dev/null
 
 echo "done."
 echo
