@@ -2,9 +2,7 @@
 //
 //   An audio transport button widget.
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//    $Id: rdtransportbutton.cpp,v 1.4.10.1 2014/05/27 22:49:45 cvs Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
@@ -33,8 +31,8 @@
 
 
 RDTransportButton::RDTransportButton(RDTransportButton::TransType type,
-				   QWidget *parent,const char *name)
-  :  QPushButton(parent,name)
+				     QWidget *parent)
+  :  QPushButton(parent)
 {
   button_type=type;
   button_state=RDTransportButton::Off;
