@@ -2,9 +2,7 @@
 //
 // Create a Rivendell Database
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: createdb.h,v 1.5 2007/02/14 21:51:02 fredg Exp $
+//   (C) Copyright 2002-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,11 +23,19 @@
 
 #include <qstring.h>
 
+#include <rdconfig.h>
 
-bool CreateDb(QString name,QString pwd);
-bool InitDb(QString name,QString pwd,QString stationname);
-bool UpdateDb(int ver);
+//
+// UpdateDB return codes
+//
+#define UPDATEDB_SUCCESS 0
+#define UPDATEDB_BACKUP_FAILED -1
+#define UPDATEDB_QUERY_FAILED -2
+
+bool CreateDb(QString name,QString pwd,RDConfig *config);
+bool InitDb(QString name,QString pwd,QString stationname,RDConfig *config);
+int UpdateDb(int ver,RDConfig *config);
 
 
-#endif
+#endif  // CREATEDB_H
 
