@@ -66,7 +66,7 @@
 //
 // Icons
 //
-#include "../icons/rivendell-22x22.xpm"
+#include "../icons/rdadmin-22x22.xpm"
 
 //
 // Global Classes
@@ -138,14 +138,15 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Create And Set Icon
   //
-  admin_rivendell_map=new QPixmap(rivendell_xpm);
+  admin_rivendell_map=new QPixmap(rdadmin_22x22_xpm);
   setIcon(*admin_rivendell_map);
 
   //
   // Load Configs
   //
-  admin_config=new RDConfig();
+  admin_config=new RDConfig(RD_CONF_FILE);
   admin_config->load();
+  admin_config->setModuleName("RDAdmin");
 
   str=QString(tr("RDAdmin")+" v"+VERSION+" - Host:");
   setCaption(QString().
@@ -157,7 +158,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   if(!OpenDb(admin_config->mysqlDbname(),admin_config->mysqlUsername(),
 	     admin_config->mysqlPassword(),admin_config->mysqlHostname(),
-	     admin_config->stationName(),true)) {
+	     admin_config->stationName(),true,admin_config)) {
     exit(1);
   }
   new RDDbHeartbeat(admin_config->mysqlHeartbeatInterval());
@@ -177,10 +178,10 @@ MainWidget::MainWidget(QWidget *parent)
   char temp[256];
   GetPrivateProfileString(RD_CONF_FILE,"Identity","Password",
 			  temp,"",255);
-  rdripc=new RDRipc(admin_config->stationName(),this);
-  rdripc->connectHost("localhost",RIPCD_TCP_PORT,temp);
   admin_station=new RDStation(admin_config->stationName(),this);
   admin_system=new RDSystem();
+  rdripc=new RDRipc(admin_station,admin_config,this);
+  rdripc->connectHost("localhost",RIPCD_TCP_PORT,temp);
 
   //
   // Log In
@@ -482,7 +483,7 @@ void MainWidget::restoreData()
   }
   delete q;
   admin_skip_backup=true;
-  UpdateDb(ver);
+  UpdateDb(ver,admin_config);
   QMessageBox::information(this,tr("Restore Complete"),
 			   tr("Restore completed successfully."));
   RDStartDaemons();
@@ -603,7 +604,7 @@ int cmdline_main(int argc,char *argv[])
   }
   if(!OpenDb(admin_config->mysqlDbname(),admin_config->mysqlUsername(),
 	     admin_config->mysqlPassword(),admin_config->mysqlHostname(),
-	     station_name,false)) {
+	     station_name,false,admin_config)) {
     return 1;
   }
 
