@@ -97,6 +97,10 @@
         <source>An event is already scheduled with this start time!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cart Notes</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HourSelector</name>
@@ -291,11 +295,11 @@ logg</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Loggen eksisterer</translation>
+        <translation type="obsolete">Loggen eksisterer</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Loggen finst frå før!</translation>
+        <translation type="obsolete">Loggen finst frå før!</translation>
     </message>
     <message>
         <source>--- end of log ---</source>
@@ -355,7 +359,7 @@ logg</translation>
     </message>
     <message>
         <source>T</source>
-        <translation>S</translation>
+        <translation type="unfinished">S</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -395,12 +399,20 @@ Tail</source>
         <source>Selected:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Vel ein logg</translation>
+        <translation type="obsolete">Vel ein logg</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -428,7 +440,7 @@ Tail</source>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>Lagre &amp;som</translation>
+        <translation type="obsolete">Lagre &amp;som</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -438,6 +450,18 @@ Tail</source>
         <source>Rename Log</source>
         <translation>Døyp om loggen</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -598,12 +622,20 @@ LASTAR PÅ NYTT</translation>
         <source>Host:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Memory Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to lock all memory</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
     <message>
         <source>Operating Mode</source>
-        <translation>Køyremodus</translation>
+        <translation type="unfinished">Køyremodus</translation>
     </message>
     <message>
         <source>LiveAssist</source>
@@ -617,6 +649,14 @@ LASTAR PÅ NYTT</translation>
         <source>Manual</source>
         <translation>Manuelt</translation>
     </message>
+    <message>
+        <source>Aux1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PostCounter</name>
