@@ -320,11 +320,11 @@ Log</source>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Lista Existe</translation>
+        <translation type="obsolete">Lista Existe</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Lista já Existe!</translation>
+        <translation type="obsolete">Lista já Existe!</translation>
     </message>
     <message>
         <source>Selected:</source>
@@ -384,7 +384,7 @@ Log</source>
     </message>
     <message>
         <source>T</source>
-        <translation>T</translation>
+        <translation type="unfinished">T</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -398,12 +398,16 @@ Log</source>
         <source>ALBUM</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Sel uma Lista</translation>
+        <translation type="obsolete">Sel uma Lista</translation>
     </message>
     <message>
         <source>NAME</source>
@@ -431,7 +435,7 @@ Log</source>
     </message>
     <message>
         <source>Save &amp;As</source>
-        <translation>Salvar &amp;Como</translation>
+        <translation type="obsolete">Salvar &amp;Como</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -441,6 +445,18 @@ Log</source>
         <source>Rename Log</source>
         <translation>Renomear lista</translation>
     </message>
+    <message>
+        <source>ALL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save As</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogLineBox</name>
@@ -602,6 +618,14 @@ LISTA</translation>
         <source>Host:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Memory Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to lock all memory</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ModeDisplay</name>
