@@ -2,9 +2,7 @@
 //
 // The Start Button for RDAirPlay Rivendell
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: start_button.cpp,v 1.27 2011/02/11 23:06:05 cvs Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,9 +26,8 @@
 #include <start_button.h>
 #include <colors.h>
 
-
-StartButton::StartButton(bool allow_pause,QWidget *parent,const char *name)
-  : QPushButton(parent,name)
+StartButton::StartButton(bool allow_pause,QWidget *parent)
+  : QPushButton(parent)
 {
   start_time_mode=RDAirPlayConf::TwentyFourHour;
   start_time=QTime();
