@@ -40,8 +40,11 @@
 #include <rdgroup_list.h>
 #include <rdsimpleplayer.h>
 
-#include <drop_listview.h>
-#include <list_reports.h>
+#include "drop_listview.h"
+#include "list_reports.h"
+#ifndef WIN32
+#include "render_dialog.h"
+#endif  // WIN32
 
 //
 // Widget Settings
@@ -84,6 +87,7 @@ class EditLog : public QDialog
   void cartDroppedData(int line,RDLogLine *ll);
   void saveData();
   void saveasData();
+  void renderasData();
   void reportsData();
   void okData();
   void cancelData();
@@ -183,6 +187,10 @@ class EditLog : public QDialog
   QLabel *edit_purgedate_label;
   QDateEdit *edit_purgedate_edit;
   QPushButton *edit_purgedate_button;
+#ifndef WIN32
+  QPushButton *edit_renderas_button;
+  RenderDialog *edit_render_dialog;
+#endif  // WIN32
 };
 
 
