@@ -234,7 +234,7 @@ popisná data</translation>
     <message>
         <source>Save
 &amp;As</source>
-        <translation>Uložit
+        <translation type="obsolete">Uložit
 &amp;jako</translation>
     </message>
     <message>
@@ -279,11 +279,11 @@ Přesto chcete uložit?</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Zápis existuje</translation>
+        <translation type="obsolete">Zápis existuje</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Zápis již existuje!</translation>
+        <translation type="obsolete">Zápis již existuje!</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
@@ -409,6 +409,22 @@ jež jsou pro vybranou službu zakázány!</translation>
         <source>Len</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditLogLine</name>
@@ -639,27 +655,27 @@ vybrané služby!</translation>
     <name>ListLogs</name>
     <message>
         <source>Select a Log</source>
-        <translation>Vybrat zápis</translation>
+        <translation type="obsolete">Vybrat zápis</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NÁZEV</translation>
+        <translation type="obsolete">NÁZEV</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>POPIS</translation>
+        <translation type="obsolete">POPIS</translation>
     </message>
     <message>
         <source>SERVICE</source>
-        <translation>SLUŽBA</translation>
+        <translation type="obsolete">SLUŽBA</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>Z&amp;rušit</translation>
+        <translation type="obsolete">Z&amp;rušit</translation>
     </message>
 </context>
 <context>
@@ -809,11 +825,11 @@ o zápisu</translation>
     </message>
     <message>
         <source>Log Exists</source>
-        <translation>Zápis existuje</translation>
+        <translation type="obsolete">Zápis existuje</translation>
     </message>
     <message>
         <source>Log Already Exists!</source>
-        <translation>Zápis již existuje!</translation>
+        <translation type="obsolete">Zápis již existuje!</translation>
     </message>
     <message>
         <source>Delete Log</source>
@@ -826,7 +842,7 @@ o zápisu</translation>
     <message>
         <source>voice tracks associated with this log.
 Continue?</source>
-        <translation>stopy hlasů spojených s tímto zápisem.
+        <translation type="obsolete">stopy hlasů spojených s tímto zápisem.
 Pokračovat?</translation>
     </message>
     <message>
@@ -843,11 +859,11 @@ Pokračovat?</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
-        <translation>RDLogedit</translation>
+        <translation type="obsolete">RDLogedit</translation>
     </message>
     <message>
         <source>Unable to delete log, audio deletion error!</source>
-        <translation>Soubor se zápisem nelze smazat, chyba při mazání zvuku!</translation>
+        <translation type="obsolete">Soubor se zápisem nelze smazat, chyba při mazání zvuku!</translation>
     </message>
     <message>
         <source>RDLogEdit -- Database Skew</source>
@@ -868,23 +884,142 @@ Vyhledejte svého správce systému kvůli aktualizaci!</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Service</source>
+        <source>Are you sure you want to delete the</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALL</source>
+        <source>log?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Filter</source>
+        <source>voice tracks associated with this log.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Clear</source>
+        <source>Continue?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show Only Recent Logs</source>
+        <source>Are you sure you want to delete these</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>logs?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>voice tracks associated with these logs.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to delete log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>audio deletion error!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RenderDialog</name>
+    <message>
+        <source>Render Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Log...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render Progress</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Render To</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished">Vybrat</translation>
+    </message>
+    <message>
+        <source>Audio Parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[now]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>As Specified</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Virtual Start Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Only Selected Events</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Include</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Stop Rendering</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Treat as PLAY</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>At STOP transition</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Render</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">Z&amp;rušit</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
