@@ -28,14 +28,15 @@
 
 #include <rddb.h>
 #include <rd.h>
+#include <rdescape_string.h>
 #include <rdevent.h>
 #include <rdcreate_log.h>
 
-#include <list_clocks.h>
-#include <add_clock.h>
-#include <edit_clock.h>
-#include <globals.h>
-#include <rename_item.h>
+#include "add_clock.h"
+#include "edit_clock.h"
+#include "globals.h"
+#include "list_clocks.h"
+#include "rename_item.h"
 
 ListClocks::ListClocks(QString *clockname,QWidget *parent)
   : QDialog(parent,"",true)
@@ -169,16 +170,12 @@ ListClocks::ListClocks(QString *clockname,QWidget *parent)
   edit_filter_box->insertItem(tr("ALL"));
   edit_filter_box->insertItem(tr("NONE"));
 
-  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
-    services_list = rduser->services();
-  } else { // RDStation::HostSec
-    QString sql="select NAME from SERVICES";
-    RDSqlQuery *q=new RDSqlQuery(sql);
-    while(q->next()) {
-      services_list.append( q->value(0).toString() );
-    }
-    delete q;
-  } 
+  QString sql="select NAME from SERVICES";
+  RDSqlQuery *q=new RDSqlQuery(sql);
+  while(q->next()) {
+    services_list.append( q->value(0).toString() );
+  }
+  delete q;
   services_list.sort();
   for ( QStringList::Iterator it = services_list.begin(); 
         it != services_list.end();
@@ -244,7 +241,7 @@ void ListClocks::addData()
 			(const char *)clockname);
   q=new RDSqlQuery(sql);
   delete q;
-  sql=RDCreateClockTableSql(RDClock::tableName(clockname));
+  sql=RDCreateClockTableSql(RDClock::tableName(clockname),log_config);
   q=new RDSqlQuery(sql);
   delete q;
   EditClock *clock_dialog=new EditClock(clockname,true,&new_clocks,this);
@@ -374,10 +371,9 @@ void ListClocks::renameData()
   q=new RDSqlQuery(sql);
   while(q->next()) {
     for(int i=0;i<168;i++) {
-      sql=QString().sprintf("update SERVICES set CLOCK%d=\"%s\"\
-                             where CLOCK%d=\"%s\"",
-			    i,(const char *)new_name,
-			    i,(const char *)item->text(0));
+      sql=QString("update SERVICE_CLOCKS set ")+
+	"CLOCK_NAME=\""+RDEscapeString(new_name)+"\" where "+
+	"CLOCK_NAME=\""+RDEscapeString(item->text(0))+"\"";
       q1=new RDSqlQuery(sql);
       delete q1;
     }
@@ -584,19 +580,21 @@ int ListClocks::ActiveClocks(QString clockname,QString *svc_list)
   QString sql;
   RDSqlQuery *q;
   QString svcname;
+  QStringList svcs;
 
-  sql="select NAME from SERVICES where ";
-  for(int i=0;i<167;i++) {
-    sql+=QString().sprintf("(CLOCK%d=\"%s\")||",i,(const char *)clockname);
-  }
-  sql+=QString().sprintf("(CLOCK167=\"%s\")",(const char *)clockname);
+  sql=QString("select SERVICE_NAME from SERVICE_CLOCKS where ")+
+    "CLOCK=\""+RDEscapeString(clockname)+"\" order by CLOCK";
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    n++;
-    *svc_list+=
-      QString().sprintf("    %s\n",(const char *)q->value(0).toString());
+    if((svcs.size()==0)||(svcs.back()!=q->value(0).toString())) {
+      svcs.push_back(q->value(0).toString());
+    }
   }
   delete q;
+  for(unsigned i=0;i<svcs.size();i++) {
+    n++;
+    *svc_list+="    "+svcs[i]+"\n";
+  }
 
   return n;
 }
@@ -612,13 +610,10 @@ void ListClocks::DeleteClock(QString clockname)
   //
   // Delete Active Clocks
   //
-  for(int i=0;i<168;i++) {
-    sql=QString().sprintf("update SERVICES set CLOCK%d=NULL\
-                             where CLOCK%d=\"%s\"",
-			  i,i,(const char *)clockname);
-    q=new RDSqlQuery(sql);
-    delete q;
-  }
+  sql=QString("delete from SERVICE_CLOCKS where ")+
+    "CLOCK=\""+RDEscapeString(clockname)+"\"";
+  q=new RDSqlQuery(sql);
+  delete q;
 
   //
   // Delete Service Associations
