@@ -107,7 +107,7 @@ MainWidget::MainWidget(QWidget *parent)
   //
   dg_station=new RDStation(dg_config->stationName(),this);
   dg_library_conf=new RDLibraryConf(dg_config->stationName(),0);
-  dg_ripc=new RDRipc(dg_config->stationName(),this);
+  dg_ripc=new RDRipc(dg_station,dg_config,this);
   connect(dg_ripc,SIGNAL(userChanged()),this,SLOT(userChangedData()));
   dg_ripc->connectHost("localhost",RIPCD_TCP_PORT,dg_config->password());
 
@@ -209,7 +209,7 @@ void MainWidget::serviceActivatedData(int index)
   if(dg_svc!=NULL) {
     delete dg_svc;
   }
-  dg_svc=new RDSvc(dg_service_box->currentText());
+  dg_svc=new RDSvc(dg_service_box->currentText(),dg_station,dg_config);
   if(dg_group!=NULL) {
     delete dg_group;
   }
@@ -391,7 +391,8 @@ bool MainWidget::WriteTrafficFile()
   // Open Output File
   //
   outname=RDDateDecode(dg_svc->importPath(RDSvc::Traffic,RDSvc::Linux),
-		       dg_date_edit->date());
+		       dg_date_edit->date(),dg_station,
+		       dg_config,dg_svc->name());
   if((f=fopen(outname,"w"))==NULL) {
     LogMessage(tr("WARNING: Unable to open traffic output file")+" \""+
 	       outname+"\" ["+strerror(errno)+"].");
