@@ -2,7 +2,7 @@
 //
 // A Batch Importer for Rivendell.
 //
-//   (C) Copyright 2002-2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2014,2016-2017 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,13 +34,14 @@
 #include <qstringlist.h>
 
 #include <rd.h>
-#include <rdcut.h>
+#include <rdaudioimport.h>
 #include <rdconf.h>
+#include <rdcut.h>
+#include <rddbheartbeat.h>
+#include <rdescape_string.h>
 #include <rdimport.h>
 #include <rdlibrary_conf.h>
-#include <rdescape_string.h>
-#include <rddbheartbeat.h>
-#include <rdaudioimport.h>
+#include <rdtempdirectory.h>
 
 volatile bool import_run=true;
 
@@ -90,6 +91,7 @@ MainObject::MainObject(QObject *parent)
   import_clear_datetimes=false;
   import_clear_dayparts=false;
   import_xml=false;
+  import_to_mono=false;
 
   //
   // Read Command Options
@@ -254,6 +256,9 @@ MainObject::MainObject(QObject *parent)
 	exit(256);
       }
     }
+    if(import_cmd->key(i)=="--to-mono") {
+      import_to_mono=true;
+    }
     if(import_cmd->key(i)=="--clear-daypart-times") {
       import_clear_dayparts=true;
       import_cmd->setProcessed(i,true);
@@ -420,6 +425,7 @@ MainObject::MainObject(QObject *parent)
   //
   import_config=new RDConfig();
   import_config->load();
+  import_config->setModuleName("rdimport");
 
   //
   // Open Database
@@ -441,19 +447,19 @@ MainObject::MainObject(QObject *parent)
   }
   new RDDbHeartbeat(import_config->mysqlHeartbeatInterval(),this);
 
-  //
-  // RIPC Connection
-  //
-  import_ripc=new RDRipc(import_config->stationName());
-  connect(import_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
-  import_ripc->
-    connectHost("localhost",RIPCD_TCP_PORT,import_config->password());
-
   //
   // Station Configuration
   //
   import_station=new RDStation(import_config->stationName());
 
+  //
+  // RIPC Connection
+  //
+  import_ripc=new RDRipc(import_station,import_config,this);
+  connect(import_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
+  import_ripc->
+    connectHost("localhost",RIPCD_TCP_PORT,import_config->password());
+
   //
   // User
   //
@@ -566,6 +572,9 @@ MainObject::MainObject(QObject *parent)
       import_single_cart=true;
     }
   }
+  if(import_to_mono) {
+    import_channels=1;
+  }
 
   //
   // Print Status Messages
@@ -583,6 +592,12 @@ MainObject::MainObject(QObject *parent)
     else {
       printf(" Log mode is OFF\n");
     }
+    if(import_to_mono) {
+      printf(" Force to Mono is ON\n");
+    }
+    else {
+      printf(" Force to Mono is OFF\n");
+    }
     if(import_normalization_level==0) {
       printf(" Normalization is OFF\n");
     }
@@ -1025,6 +1040,12 @@ MainObject::Result MainObject::ImportFile(const QString &filename,
     QString groupname=effective_group->name();
     found_cart=RunPattern(import_metadata_pattern,RDGetBasePart(filename),
 			  wavedata,&groupname);
+    if(!wavedata->checkDateTimes()) {
+      PrintLogDateTime(stderr);
+      fprintf(stderr,
+	      " File \"%s\": End date/time cannot be prior to start date/time, ignoring...\n",
+	      (const char *)filename.utf8());
+    }
     if(groupname!=effective_group->name()) {
       delete effective_group;
       effective_group=new RDGroup(groupname);
@@ -1468,7 +1489,7 @@ RDWaveFile *MainObject::FixFile(const QString &filename,RDWaveData *wavedata)
   // Copy File
   //
   import_temp_fix_filename=
-    QString(tempnam(RDTempDir(),"rdfix"))+QString(".wav");
+    QString(tempnam(RDTempDirectory::basePath(),"rdfix"))+QString(".wav");
   if(import_temp_fix_filename.isNull()) {
     return NULL;
   }
@@ -1638,6 +1659,11 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
   QString value;
   QChar delimiter;
   bool found_cartnum=false;
+  bool found_end_date=false;
+  bool found_start_time=false;
+  bool found_end_time=false;
+  QTime time;
+  QDate date;
 
   //
   // Initialize Pattern Parser
@@ -1658,85 +1684,132 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
     if(macro_active) {
       if((filename.at(i)==delimiter)||(i==filename.length())) {
 	switch(field) {
-	  case 'a':
-	    wavedata->setArtist(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'a':
+	  wavedata->setArtist(value);
+	  wavedata->setMetadataFound(true);
+	  break;
+  
+	case 'b':
+	  wavedata->setLabel(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'b':
-	    wavedata->setLabel(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'c':
+	  wavedata->setClient(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'c':
-	    wavedata->setClient(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'e':
+	  wavedata->setAgency(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'e':
-	    wavedata->setAgency(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'g':
+	  *groupname=value;
+	  break;
 
-	  case 'g':
-	    *groupname=value;
-	    break;
+	case 'i':
+	  wavedata->setDescription(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'i':
-	    wavedata->setDescription(value);
+	case 'k':
+	  time=QTime::fromString(value);
+	  if(time.isValid()) {
+	    wavedata->setStartTime(time);
+	    found_start_time=true;
 	    wavedata->setMetadataFound(true);
-	    break;
+	  }
+	  break;
 
-	  case 'l':
-	    wavedata->setAlbum(value);
+	case 'K':
+	  time=QTime::fromString(value);
+	  if(time.isValid()) {
+	    wavedata->setEndTime(time);
+	    found_end_time=true;
 	    wavedata->setMetadataFound(true);
-	    break;
+	  }
+	  break;
 
-	  case 'm':
-	    wavedata->setComposer(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'l':
+	  wavedata->setAlbum(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'n':
-	    wavedata->setCutId(value);
-	    wavedata->setMetadataFound(true);
-	    found_cartnum=true;
-	    break;
+	case 'm':
+	  wavedata->setComposer(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'o':
-	    wavedata->setOutCue(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'n':
+	  wavedata->setCutId(value);
+	  wavedata->setMetadataFound(true);
+	  found_cartnum=true;
+	  break;
 
-	  case 'p':
-	    wavedata->setPublisher(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'o':
+	  wavedata->setOutCue(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'r':
-	    wavedata->setConductor(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'p':
+	  wavedata->setPublisher(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 's':
-	    wavedata->setTmciSongId(value);
+	case 'q':
+	  date=QDate::fromString(value,Qt::ISODate);
+	  if(date.isValid()) {
+	    wavedata->setStartDate(date);
 	    wavedata->setMetadataFound(true);
-	    break;
+	    if(!found_end_date) {
+	      wavedata->setEndDate(date);
+	      if(!found_end_time) {
+		wavedata->setEndTime(QTime(23,59,59));
+	      }
+	    }
+	    if(!found_start_time) {
+	      wavedata->setStartTime(QTime(0,0,0,1));
+	    }
+	  }
+	  break;
 
-	  case 't':
-	    wavedata->setTitle(value);
+	case 'Q':
+	  date=QDate::fromString(value,Qt::ISODate);
+	  if(date.isValid()) {
+	    wavedata->setEndDate(date);
+	    found_end_date=true;
 	    wavedata->setMetadataFound(true);
-	    break;
+	    if(!found_end_time) {
+	      wavedata->setEndTime(QTime(23,59,59));
+	    }
+	  }
+	  break;
 
-	  case 'u':
-	    wavedata->setUserDefined(value);
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 'r':
+	  wavedata->setConductor(value);
+	  wavedata->setMetadataFound(true);
+	  break;
 
-	  case 'y':
-	    wavedata->setReleaseYear(value.toInt());
-	    wavedata->setMetadataFound(true);
-	    break;
+	case 's':
+	  wavedata->setTmciSongId(value);
+	  wavedata->setMetadataFound(true);
+	  break;
+
+	case 't':
+	  wavedata->setTitle(value);
+	  wavedata->setMetadataFound(true);
+	  break;
+
+	case 'u':
+	  wavedata->setUserDefined(value);
+	  wavedata->setMetadataFound(true);
+	  break;
+
+	case 'y':
+	  wavedata->setReleaseYear(value.toInt());
+	  wavedata->setMetadataFound(true);
+	  break;
 	}
 	value="";
 	if((ptr>=pattern.length())||(i==filename.length())) {
@@ -1778,6 +1851,7 @@ bool MainObject::RunPattern(const QString &pattern,const QString &filename,
       }
     }
   }
+
   return found_cartnum;
 }
 
@@ -1798,11 +1872,15 @@ bool MainObject::VerifyPattern(const QString &pattern)
       case 'e':
       case 'g':
       case 'i':
+      case 'k':
+      case 'K':
       case 'l':
       case 'm':
       case 'n':
       case 'o':
       case 'p':
+      case 'q':
+      case 'Q':
       case 'r':
       case 's':
       case 't':
